This dataset contains the simulated returns used in the numerical example of Marcos Lopez de Prado's paper, hence the name mldp_returns. The Python code used to reproduce this simulated data is kindly provided by the author in the supplementary material of his paper.